==> jdk-21.0.9.10.1p0v0.tgz: jdk.localedata/sun/util/resources/cldr/ext/CurrencyNames_zu.java <==
/*
 * Copyright (c) 2012, 2026, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that either
 * (a) this copyright and permission notice appear with all copies
 * of the Data Files or Software, or
 * (b) this copyright and permission notice appear in associated
 * Documentation.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class CurrencyNames_zu extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "AED", "AED" },
            { "AFN", "AFN" },
            { "ALL", "ALL" },
            { "AMD", "AMD" },
            { "ANG", "ANG" },
            { "AOA", "AOA" },
            { "AWG", "AWG" },
            { "AZN", "AZN" },
            { "BAM", "BAM" },
            { "BBD", "BBD" },
            { "BDT", "BDT" },
            { "BGN", "BGN" },
            { "BHD", "BHD" },
            { "BIF", "BIF" },
            { "BMD", "BMD" },
            { "BND", "BND" },
            { "BOB", "BOB" },
            { "BSD", "BSD" },
            { "BTN", "BTN" },
            { "BWP", "BWP" },
            { "BYN", "BYN" },
            { "BYR", "BYR" },
            { "BZD", "BZD" },
            { "CDF", "CDF" },
            { "CHF", "CHF" },
            { "CLP", "CLP" },
            { "COP", "COP" },
            { "CRC", "CRC" },
            { "CUC", "CUC" },
            { "CUP", "CUP" },
            { "CVE", "CVE" },
            { "CZK", "CZK" },
            { "DJF", "DJF" },
            { "DKK", "DKK" },
            { "DOP", "DOP" },
            { "DZD", "DZD" },
            { "EGP", "EGP" },
            { "ERN", "ERN" },
            { "ETB", "ETB" },
            { "FJD", "FJD" },
            { "FKP", "FKP" },
            { "GEL", "GEL" },
            { "GHS", "GHS" },
            { "GIP", "GIP" },
            { "GMD", "GMD" },
            { "GNF", "GNF" },
            { "GTQ", "GTQ" },
            { "GYD", "GYD" },
            { "HNL", "HNL" },
            { "HRK", "HRK" },
            { "HTG", "HTG" },
            { "HUF", "HUF" },
            { "IDR", "IDR" },
            { "IQD", "IQD" },
            { "IRR", "IRR" },
            { "ISK", "ISK" },
            { "JMD", "JMD" },
            { "JOD", "JOD" },
            { "KES", "KES" },
            { "KGS", "KGS" },
            { "KHR", "KHR" },
            { "KMF", "KMF" },
            { "KPW", "KPW" },
            { "KWD", "KWD" },
            { "KYD", "KYD" },
            { "KZT", "KZT" },
            { "LAK", "LAK" },
            { "LBP", "LBP" },
            { "LKR", "LKR" },
            { "LRD", "LRD" },
            { "LYD", "LYD" },
            { "MAD", "MAD" },
            { "MDL", "MDL" },
            { "MGA", "MGA" },
            { "MKD", "MKD" },
            { "MMK", "MMK" },
            { "MNT", "MNT" },
            { "MOP", "MOP" },
            { "MRO", "MRO" },
            { "MUR", "MUR" },
            { "MVR", "MVR" },
            { "MWK", "MWK" },
            { "MYR", "MYR" },
            { "MZN", "MZN" },
            { "NAD", "NAD" },
            { "NGN", "NGN" },
            { "NIO", "NIO" },
            { "NOK", "NOK" },
            { "NPR", "NPR" },
            { "OMR", "OMR" },
            { "PAB", "PAB" },
            { "PEN", "PEN" },
            { "PGK", "PGK" },
            { "PHP", "PHP" },
            { "PKR", "PKR" },
            { "PLN", "PLN" },
            { "PYG", "PYG" },
            { "QAR", "QAR" },
            { "RON", "RON" },
            { "RSD", "RSD" },
            { "RUB", "RUB" },
            { "RWF", "RWF" },
            { "SAR", "SAR" },
            { "SBD", "SBD" },
            { "SCR", "SCR" },
            { "SDG", "SDG" },
            { "SEK", "SEK" },
            { "SGD", "SGD" },
            { "SHP", "SHP" },
            { "SLL", "SLL" },
            { "SOS", "SOS" },
            { "SRD", "SRD" },
            { "SSP", "SSP" },
            { "STD", "STD" },
            { "SYP", "SYP" },
            { "SZL", "SZL" },
            { "THB", "\u0e3f" },
            { "TJS", "TJS" },
            { "TMT", "TMT" },
            { "TND", "TND" },
            { "TOP", "TOP" },
            { "TRY", "TRY" },
            { "TTD", "TTD" },
            { "TZS", "TZS" },
            { "UAH", "UAH" },
            { "UGX", "UGX" },
            { "USD", "$" },
            { "UYU", "UYU" },
            { "UZS", "UZS" },
            { "VEF", "VEF" },
            { "VUV", "VUV" },
            { "WST", "WST" },
            { "YER", "YER" },
            { "ZAR", "R" },
            { "ZMW", "ZMW" },
            { "aed", "i-Dirham yase-United Arab Emirates" },
            { "afn", "i-Afghan Afghani" },
            { "all", "i-Albanian Lek" },
            { "amd", "i-Armenian Dram" },
            { "ang", "i-Netherlands Antillean Guilder" },
            { "aoa", "i-Angolan Kwanza" },
            { "ars", "i-Argentina Peso" },
            { "aud", "i-Austrilian Dollar" },
            { "awg", "i-Aruban Florin" },
            { "azn", "i-Azerbaijani Manat" },
            { "bam", "i-Bosnia-Herzegovina Convertible Mark" },
            { "bbd", "i-Barbadian Dollar" },
            { "bdt", "i-Bangladeshi Taka" },
            { "bgn", "i-Bulgarian Lev" },
            { "bhd", "i-Bahraini Dinar" },
            { "bif", "i-Burundian Franc" },
            { "bmd", "i-Bermudan Dollar" },
            { "bnd", "i-Brunei Dollar" },
            { "bob", "i-Bolivian Boliviano" },
            { "brl", "i-Brazilian Real" },
            { "bsd", "i-Bahamian Dollar" },
            { "btn", "i-Bhutanese Ngultrum" },
            { "bwp", "i-Botswana Pula" },
            { "byn", "i-Belarusian Ruble" },
            { "byr", "i-Belarusian Ruble (2000\u20132016)" },
            { "bzd", "i-Belize Dollar" },
            { "cad", "i-Candian Dollar" },
            { "cdf", "i-Congolese Franc" },
            { "chf", "i-Swiss Franc" },
            { "clp", "i-Chilean Peso" },
            { "cnh", "i-CNH" },
            { "cny", "i-Chinese Yuan" },
            { "cop", "i-Colombian Peso" },
            { "crc", "i-Costa Rican Col\u00f3n" },
            { "cuc", "i-Cuban Convertable Peso" },
            { "cup", "i-Cuban Peso" },
            { "cve", "i-Cape Verdean Escudo" },
            { "czk", "i-Czech Republic Koruna" },
            { "djf", "i-Djiboutian Franc" },
            { "dkk", "i-Danish Krone" },
            { "dop", "i-Dominican Peso" },
            { "dzd", "i-Algerian Dinar" },
            { "egp", "i-Egyptian Pound" },
            { "ern", "i-Eritrean Nakfa" },
            { "etb", "i-Ethopian Birr" },
            { "eur", "i-Euro" },
            { "fjd", "i-Fijian Dollar" },
            { "fkp", "i-Falkland Islands Pound" },
            { "gbp", "i-British Pound" },
            { "gel", "i-Georgian Lari" },
            { "ghs", "i-Ghanaian Cedi" },
            { "gip", "i-Gibraltar Pound" },
            { "gmd", "i-Gambian Dalasi" },
            { "gnf", "i-Gunean Franc" },
            { "gtq", "i-Guatemalan Quetzal" },
            { "gyd", "i-Guyanaese Dollar" },
            { "hkd", "i-Hong Kong Dollar" },
            { "hnl", "i-Honduran Lempira" },
            { "hrk", "i-Croatian Kuna" },
            { "htg", "i-Haitian Gourde" },
            { "huf", "i-Hungarian Forint" },
            { "idr", "i-Indonesian Rupiah" },
            { "ils", "i-Israeli New Sheqel" },
            { "inr", "i-Indian Rupee" },
            { "iqd", "i-Iraqi Dinar" },
            { "irr", "i-Iranian Rial" },
            { "isk", "i-Icelandic Kr\u00f3na" },
            { "jmd", "i-Jamaican Dollar" },
            { "jod", "i-Jordanian Dinar" },
            { "jpy", "i-Japanese Yen" },
            { "kes", "i-Kenyan Shilling" },
            { "kgs", "i-Kyrgystani Som" },
            { "khr", "i-Cambodian Riel" },
            { "kmf", "i-Comorian Franc" },
            { "kpw", "i-North Korean Won" },
            { "krw", "i-South Korean Won" },
            { "kwd", "i-Kuwaiti Dinar" },
            { "kyd", "i-Cayman Islands Dollar" },
            { "kzt", "i-Kazakhstani Tenge" },
            { "lak", "i-Laotian Kip" },
            { "lbp", "i-Lebanese Pound" },
            { "lkr", "i-Sri Lankan Rupee" },
            { "lrd", "i-Liberian Dollar" },
            { "lsl", "i-Lesotho Loti" },
            { "ltl", "i-Lithuanian Litas" },
            { "lvl", "i-Latvian Lats" },
            { "lyd", "i-Libyan Dinar" },
            { "mad", "i-Moroccan Dirham" },
            { "mdl", "i-Moldovan Leu" },
            { "mga", "i-Malagasy Ariary" },
            { "mkd", "i-Macedonian Denar" },
            { "mmk", "i-Myanma Kyat" },
            { "mnt", "i-Mongolian Tugrik" },
            { "mop", "i-Macanese Pataca" },
            { "mro", "i-Mauritanian Ouguiya (1973\u20132017)" },
            { "mru", "i-Mauritanian Ouguiya" },
            { "mur", "i-Mauritian Rupee" },
            { "mvr", "i-Maldivian Rufiyana" },
            { "mwk", "i-Malawian Kwacha" },
            { "mxn", "i-Mexican Peso" },
            { "myr", "i-Malaysian Ringgit" },
            { "mzn", "i-Mozambican Metical" },
            { "nad", "i-Namibian Dollar" },
            { "ngn", "i-Nigerian Naira" },
            { "nio", "i-Nicaraguan C\u00f3rdoba" },
            { "nok", "i-Norwegian Krone" },
            { "npr", "i-Nepalese Rupee" },
            { "nzd", "i-New Zealand Dollar" },
            { "omr", "i-Omani Rial" },
            { "pab", "i-Panamanian Balboa" },
            { "pen", "i-Peruvian Nuevo Sol" },
            { "pgk", "i-Papua New Guinean Kina" },
            { "php", "i-Philippine Peso" },
            { "pkr", "i-Pakistani Rupee" },
            { "pln", "i-Polish Zloty" },
            { "pyg", "i-Paraguayan Guarani" },
            { "qar", "i-Qatari Rial" },
            { "ron", "i-Romanian Leu" },
            { "rsd", "i-Serbian Dinar" },
            { "rub", "i-Russian Ruble" },
            { "rwf", "i-Rwandan Franc" },
            { "sar", "i-Saudi Riyal" },
            { "sbd", "i-Solomon Islands Dollar" },
            { "scr", "i-Seychellois Rupee" },
            { "sdg", "i-Sudanese Pound" },
            { "sek", "i-Swedish Krona" },
            { "sgd", "i-Singapore Dollar" },
            { "shp", "i-Saint Helena Pound" },
            { "sll", "i-Sierra Leonean Leone" },
            { "sos", "i-Somali Shilling" },
            { "srd", "i-Surinamese Dollar" },
            { "ssp", "i-South Sudanese Pound" },
            { "std", "i-S\u00e3o Tom\u00e9 kanye ne-Pr\u00edncipe Dobra (1977\u20132017)" },
            { "stn", "i-S\u00e3o Tom\u00e9 kanye ne-Pr\u00edncipe Dobra" },
            { "syp", "i-Syrian Pound" },
            { "szl", "i-Swazi Lilangeni" },
            { "thb", "i-Thai Baht" },
            { "tjs", "i-Tajikistani Somoni" },
            { "tmt", "i-Turkmenistani Manat" },
            { "tnd", "i-Tunisian Dinar" },
            { "top", "i-Tongan Pa\u02bbanga" },
            { "try", "i-Turkish Lira" },
            { "ttd", "i-Trinidad and Tobago Dollar" },
            { "twd", "i-New Taiwan Dollar" },
            { "tzs", "i-Tanzanian Shilling" },
            { "uah", "i-Ukrainian Hryvnia" },
            { "ugx", "i-Ugandan Shilling" },
            { "usd", "i-US Dollar" },
            { "uyu", "i-Uruguayan Peso" },
            { "uzs", "i-Uzbekistan Som" },
            { "vef", "i-Venezuelan Bol\u00edvar (2008\u20132018)" },
            { "ves", "i-Venezuelan Bol\u00edvar" },
            { "vnd", "i-Vietnamese Dong" },
            { "vuv", "i-Vanuatu Vatu" },
            { "wst", "i-Samoan Tala" },
            { "xaf", "i-Central African CFA Franc" },
            { "xcd", "i-East Caribbean Dollar" },
            { "xof", "i-West African CFA Franc" },
            { "xpf", "i-CFP Franc" },
            { "xxx", "imali engaziwa" },
            { "yer", "i-Yemeni Rial" },
            { "zar", "i-South African Rand" },
            { "zmk", "i-Zambian Kwacha (1968\u20132012)" },
            { "zmw", "i-Zambian Kwacha" },
        };
        return data;
    }
}

==> jdk-25.0.1.8.1p1v0.tgz: jdk.localedata/sun/util/resources/cldr/ext/CurrencyNames_zu.java <==
/*
 * Copyright (c) 2012, 2026, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that either
 * (a) this copyright and permission notice appear with all copies
 * of the Data Files or Software, or
 * (b) this copyright and permission notice appear in associated
 * Documentation.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class CurrencyNames_zu extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final Object[][] data = new Object[][] {
            { "PHP", "PHP" },
            { "THB", "\u0e3f" },
            { "USD", "$" },
            { "ZAR", "R" },
            { "aed", "i-Dirham yase-United Arab Emirates" },
            { "afn", "i-Afghan Afghani" },
            { "all", "i-Albanian Lek" },
            { "amd", "i-Armenian Dram" },
            { "ang", "i-Netherlands Antillean Guilder" },
            { "aoa", "i-Angolan Kwanza" },
            { "ars", "i-Argentina Peso" },
            { "aud", "i-Austrilian Dollar" },
            { "awg", "i-Aruban Florin" },
            { "azn", "i-Azerbaijani Manat" },
            { "bam", "i-Bosnia-Herzegovina Convertible Mark" },
            { "bbd", "i-Barbadian Dollar" },
            { "bdt", "i-Bangladeshi Taka" },
            { "bgn", "i-Bulgarian Lev" },
            { "bhd", "i-Bahraini Dinar" },
            { "bif", "i-Burundian Franc" },
            { "bmd", "i-Bermudan Dollar" },
            { "bnd", "i-Brunei Dollar" },
            { "bob", "i-Bolivian Boliviano" },
            { "brl", "i-Brazilian Real" },
            { "bsd", "i-Bahamian Dollar" },
            { "btn", "i-Bhutanese Ngultrum" },
            { "bwp", "i-Botswana Pula" },
            { "byn", "i-Belarusian Ruble" },
            { "byr", "i-Belarusian Ruble (2000\u20132016)" },
            { "bzd", "i-Belize Dollar" },
            { "cad", "i-Candian Dollar" },
            { "cdf", "i-Congolese Franc" },
            { "chf", "i-Swiss Franc" },
            { "clp", "i-Chilean Peso" },
            { "cnh", "i-CNH" },
            { "cny", "i-Chinese Yuan" },
            { "cop", "i-Colombian Peso" },
            { "crc", "i-Costa Rican Col\u00f3n" },
            { "cuc", "i-Cuban Convertable Peso" },
            { "cup", "i-Cuban Peso" },
            { "cve", "i-Cape Verdean Escudo" },
            { "czk", "i-Czech Republic Koruna" },
            { "djf", "i-Djiboutian Franc" },
            { "dkk", "i-Danish Krone" },
            { "dop", "i-Dominican Peso" },
            { "dzd", "i-Algerian Dinar" },
            { "egp", "i-Egyptian Pound" },
            { "ern", "i-Eritrean Nakfa" },
            { "etb", "i-Ethopian Birr" },
            { "eur", "i-Euro" },
            { "fjd", "i-Fijian Dollar" },
            { "fkp", "i-Falkland Islands Pound" },
            { "gbp", "i-British Pound" },
            { "gel", "i-Georgian Lari" },
            { "ghs", "i-Ghanaian Cedi" },
            { "gip", "i-Gibraltar Pound" },
            { "gmd", "i-Gambian Dalasi" },
            { "gnf", "i-Gunean Franc" },
            { "gtq", "i-Guatemalan Quetzal" },
            { "gyd", "i-Guyanaese Dollar" },
            { "hkd", "i-Hong Kong Dollar" },
            { "hnl", "i-Honduran Lempira" },
            { "hrk", "i-Croatian Kuna" },
            { "htg", "i-Haitian Gourde" },
            { "huf", "i-Hungarian Forint" },
            { "idr", "i-Indonesian Rupiah" },
            { "ils", "i-Israeli New Sheqel" },
            { "inr", "i-Indian Rupee" },
            { "iqd", "i-Iraqi Dinar" },
            { "irr", "i-Iranian Rial" },
            { "isk", "i-Icelandic Kr\u00f3na" },
            { "jmd", "i-Jamaican Dollar" },
            { "jod", "i-Jordanian Dinar" },
            { "jpy", "i-Japanese Yen" },
            { "kes", "i-Kenyan Shilling" },
            { "kgs", "i-Kyrgystani Som" },
            { "khr", "i-Cambodian Riel" },
            { "kmf", "i-Comorian Franc" },
            { "kpw", "i-North Korean Won" },
            { "krw", "i-South Korean Won" },
            { "kwd", "i-Kuwaiti Dinar" },
            { "kyd", "i-Cayman Islands Dollar" },
            { "kzt", "i-Kazakhstani Tenge" },
            { "lak", "i-Laotian Kip" },
            { "lbp", "i-Lebanese Pound" },
            { "lkr", "i-Sri Lankan Rupee" },
            { "lrd", "i-Liberian Dollar" },
            { "lsl", "i-Lesotho Loti" },
            { "ltl", "i-Lithuanian Litas" },
            { "lvl", "i-Latvian Lats" },
            { "lyd", "i-Libyan Dinar" },
            { "mad", "i-Moroccan Dirham" },
            { "mdl", "i-Moldovan Leu" },
            { "mga", "i-Malagasy Ariary" },
            { "mkd", "i-Macedonian Denar" },
            { "mmk", "i-Myanma Kyat" },
            { "mnt", "i-Mongolian Tugrik" },
            { "mop", "i-Macanese Pataca" },
            { "mro", "i-Mauritanian Ouguiya (1973\u20132017)" },
            { "mru", "i-Mauritanian Ouguiya" },
            { "mur", "i-Mauritian Rupee" },
            { "mvr", "i-Maldivian Rufiyana" },
            { "mwk", "i-Malawian Kwacha" },
            { "mxn", "i-Mexican Peso" },
            { "myr", "i-Malaysian Ringgit" },
            { "mzn", "i-Mozambican Metical" },
            { "nad", "i-Namibian Dollar" },
            { "ngn", "i-Nigerian Naira" },
            { "nio", "i-Nicaraguan C\u00f3rdoba" },
            { "nok", "i-Norwegian Krone" },
            { "npr", "i-Nepalese Rupee" },
            { "nzd", "i-New Zealand Dollar" },
            { "omr", "i-Omani Rial" },
            { "pab", "i-Panamanian Balboa" },
            { "pen", "i-Peruvian Nuevo Sol" },
            { "pgk", "i-Papua New Guinean Kina" },
            { "php", "i-Philippine Peso" },
            { "pkr", "i-Pakistani Rupee" },
            { "pln", "i-Polish Zloty" },
            { "pyg", "i-Paraguayan Guarani" },
            { "qar", "i-Qatari Rial" },
            { "ron", "i-Romanian Leu" },
            { "rsd", "i-Serbian Dinar" },
            { "rub", "i-Russian Ruble" },
            { "rwf", "i-Rwandan Franc" },
            { "sar", "i-Saudi Riyal" },
            { "sbd", "i-Solomon Islands Dollar" },
            { "scr", "i-Seychellois Rupee" },
            { "sdg", "i-Sudanese Pound" },
            { "sek", "i-Swedish Krona" },
            { "sgd", "i-Singapore Dollar" },
            { "shp", "i-Saint Helena Pound" },
            { "sle", "i-Sierra Leonean Leone" },
            { "sll", "i-Sierra Leonean Leone (1964\u20142022)" },
            { "sos", "i-Somali Shilling" },
            { "srd", "i-Surinamese Dollar" },
            { "ssp", "i-South Sudanese Pound" },
            { "std", "i-S\u00e3o Tom\u00e9 kanye ne-Pr\u00edncipe Dobra (1977\u20132017)" },
            { "stn", "i-S\u00e3o Tom\u00e9 kanye ne-Pr\u00edncipe Dobra" },
            { "syp", "i-Syrian Pound" },
            { "szl", "i-Swazi Lilangeni" },
            { "thb", "i-Thai Baht" },
            { "tjs", "i-Tajikistani Somoni" },
            { "tmt", "i-Turkmenistani Manat" },
            { "tnd", "i-Tunisian Dinar" },
            { "top", "i-Tongan Pa\u02bbanga" },
            { "try", "i-Turkish Lira" },
            { "ttd", "i-Trinidad and Tobago Dollar" },
            { "twd", "i-New Taiwan Dollar" },
            { "tzs", "i-Tanzanian Shilling" },
            { "uah", "i-Ukrainian Hryvnia" },
            { "ugx", "i-Ugandan Shilling" },
            { "usd", "i-US Dollar" },
            { "uyu", "i-Uruguayan Peso" },
            { "uzs", "i-Uzbekistan Som" },
            { "vef", "i-Venezuelan Bol\u00edvar (2008\u20132018)" },
            { "ves", "i-Venezuelan Bol\u00edvar" },
            { "vnd", "i-Vietnamese Dong" },
            { "vuv", "i-Vanuatu Vatu" },
            { "wst", "i-Samoan Tala" },
            { "xaf", "i-Central African CFA Franc" },
            { "xcd", "i-East Caribbean Dollar" },
            { "xof", "i-West African CFA Franc" },
            { "xpf", "i-CFP Franc" },
            { "xxx", "imali engaziwa" },
            { "yer", "i-Yemeni Rial" },
            { "zar", "i-South African Rand" },
            { "zmk", "i-Zambian Kwacha (1968\u20132012)" },
            { "zmw", "i-Zambian Kwacha" },
        };
        return data;
    }
}
